@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: German homepage translation
-# Copyright (C) 2004-2012 Carsten Gnörlich
+# Copyright (C) 2004-2010 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -15,10 +15,10 @@ begin_page();
 howto_headline("Datenträger-Abbild rekonstruieren", "Grundeinstellungen", "images/fix-icon.png");
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
 <?php begin_screen_shot("Einstellungsdialog aufrufen.","global-prefs-invoke.png"); ?>
-<table><tr><td class="valignt"><img src="../images/prefs-icon.png" alt="Bedienelement: Eigenschaften (Auswahlknopf)" class="valignb"></td>
+<table><tr><td valign="top"><img src="../images/prefs-icon.png" valign="bottom"></td>
 <td>Die nachfolgend besprochenen Reiterkarten finden Sie
 im Einstellungsdialog. Das zum Aufruf verwendete Symbol ist
 in dem Bildschirmfoto grün markiert (Anklicken vergrößert das Bild).
@@ -49,7 +49,6 @@ dazu gibt es in den <a href="howtos43.php#21h">fortgeschrittenen Einstellungen</
 <p>
 <?php end_screen_shot(); ?>
 
-<a name="reading_attempts"></a>
 <?php begin_screen_shot("Reiterkarte \"Leseversuche\".","fix-prefs-read-attempts.png"); ?>
 <b>Reiterkarte "Leseversuche".</b> Die Stärke des angepaßten Leseverfahrens besteht darin,
 die noch lesbaren Sektoren auf dem Datenträger zu finden und sich nicht mit dem Einlesen
@@ -78,7 +77,7 @@ keine Auswirkungen auf das Einlesen von Datenträgern.
 
 <a href="howtos42.php">Abbild einlesen und Daten wiederherstellen...</a>
 
-<!-- do not change below -->
+<!--- do not change below --->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
