@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: German homepage translation
-# Copyright (C) 2004-2012 Carsten Gnörlich
+# Copyright (C) 2004-2010 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -21,24 +21,6 @@ $news_counter = 0;
 
 news_headline("Neues über dvdisaster");
 
-news_item("07.04.2012", "dvdisaster 0.72.4 veröffentlicht", "
-Anpassung an aktuelle Versionen von GNU/Linux, FreeBSD und NetBSD.
-", 21, "2012-04-07T01:00:00Z", "2012-04-07T01:00:00Z");
-
-
-news_item("05.10.2011", "dvdisaster 0.72.3 veröffentlicht", "
-Die \"Vergleichen\"-Funktion hing bei der Verarbeitung von 
-RS01-Fehlerkorrektur-Dateien, die größer als 2GB sind (die
-Fehlerkorrektur-Dateien selbst werden korrekt erzeugt).
-Volodymyr Bychkoviak fand das Problem und schickte eine
-Korrektur.
-", 20, "2011-10-05T01:00:00Z", "2011-10-05T01:00:00Z");
-
-news_item("28.07.2011", "Dokumentation ergänzt", "
-Die zwischenzeitlich verlorengegangenen <a href=\"qa30.php\">Hintergrundinformationen</a> aus der Dokumentation von Version 0.70 wurden überarbeitet und wieder
-online gestellt.
-", 19, "2011-07-28T00:00:00Z", "2011-07-28T00:00:00Z");
-
 news_item("21.11.2010", "dvdisaster 0.79.3 veröffentlicht", "
 Ab dieser Version wird unter Linux per Voreinstellung der
 SG_IO-Treiber zum Zugriff auf die optischen Laufwerke verwendet.
@@ -82,6 +64,46 @@ finden Sie Informationen darüber, was gerade geändert wurde und wie
 Sie beim Testen mithelfen können.
 ", 14, "2010-02-07T00:00:00Z", "2010-02-07T00:00:00Z");
 
+
+news_item("01.10.2009", "Einschätzung zu potentiellen Sicherheitslücken in der GTK-Bibliothek für Windows", "
+Die Windows-Versionen von dvdisaster 0.70.x/0.72.x werden mit einer alten Version 
+der GTK-Bibliothek
+ausgeliefert, die Schwachstellen in der Verarbeitung von Bilddateien aufweist.
+Um die Lücke auszunutzen, müssen manipulierte Bilder aus
+einer externen Quelle nachgeladen werden. Da dvdisaster
+keine derartigen Funktionen beinhaltet, ist diese Schwachstelle als nicht 
+gefährlich anzusehen.<p>
+Ein Auswechseln von GTK innerhalb von dvdisaster 0.70.x/0.72.x wird nicht
+empfohlen, da sich in neueren GTK-Versionen einige Schnittstellen geändert
+haben. Der Austausch kann daher zu Fehlfunktionen führen.<p>
+Die Windows-Version von dvdisaster 0.79.1 wird mit entsprechend überarbeiteten
+Schnittstellen und einer aktuellen Version von GTK ausgeliefert werden.<p>
+An dieser Stelle vielen Dank an alle Nutzer, die einen Hinweis auf die
+Schwachstelle gegeben haben. 
+", 13, "2009-10-01T00:00:00Z", "2009-10-01T00:00:00Z");
+
+news_item("10.08.2009", "Projektseiten auf SourceForge nicht aktuell", "
+Aufgrund von Änderungen in der Funktionalität von SourceForge
+können die Inhalte der News, Downloads und des CVS nicht zeitnah
+hochgeladen werden. Bitte nutzen Sie stattdessen die entsprechenden
+Rubriken auf diesen Seiten (http://dvdisaster.net).
+", 12, "2009-08-10T00:00:00Z", "2009-08-10T00:00:00Z");
+
+news_item("08.08.2009", "dvdisaster 0.72.1 veröffentlicht", "
+Pablo Almeida hat die Bildschirmtexte ins Portugiesische übersetzt.
+Es wurde eine Umgehungslösung eingebaut um Win XP vom Einfrieren 
+bei bestimmten CD-RW/Laufwerks-Kombinationen abzuhalten.<p>
+<i>Aktueller Hinweis: Die Umgehungslösung ist nicht vollständig.
+Falls das Problem immer noch besteht, probieren Sie bitte Version 0.79.x aus.</i>
+", 11, "2009-08-08T00:00:00Z", "2010-02-06T00:00:00Z");
+
+news_item("04.07.2009", "dvdisaster 0.72 veröffentlicht", "
+Dies ist die erste stabile Version des 0.72er-Zweiges.
+Igor Gorbounov hat die russische online-Dokumentation vervollständigt
+und es wurden noch einige kleine Fehler aus dem ersten 
+Veröffentlichungskandidaten behoben.<p>
+", 10, "2009-07-04T00:00:00Z", "2009-07-04T00:00:00Z");
+
 news_finalize();
 
 if($news_flash == 0) 
