@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: English homepage translation
-# Copyright (C) 2004-2012 Carsten Gnörlich
+# Copyright (C) 2004-2010 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -15,10 +15,10 @@ begin_page();
 howto_headline("Recovering media images", "Basic settings", "images/fix-icon.png");
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
 <?php begin_screen_shot("Opening the configuration dialog.","global-prefs-invoke.png"); ?>
-<table><tr><td class="valignt"><img src="../images/prefs-icon.png" alt="dvdisaster UI: Preferences (button)" class="valignb"></td>
+<table><tr><td valign="top"><img src="../images/prefs-icon.png" valign="bottom"></td>
 <td>The following tabs are found in the configuration dialog.
 Open the dialog by selecting the symbol marked green in the screen shot
 (click the image to expand it). The symbol may look different
@@ -48,7 +48,6 @@ Some drives might work better using the raw reading mode "21h". See the
 <a href="howtos43.php#21h">advanced settings</a> for more information.<p>
 <?php end_screen_shot(); ?>
 
-<a name="reading_attempts"></a>
 <?php begin_screen_shot("\"Reading attempts\" tab.","fix-prefs-read-attempts.png"); ?>
 <b>"Reading attempts" tab.</b> The strength of the adaptive reading strategy lies in
 finding the still readable sectors and avoiding the lengthy process of trying to read
@@ -78,7 +77,7 @@ but these have no further effects on the reading process.
 
 <a href="howtos42.php">Reading the medium and recovering its contents...</a>
 
-<!-- do not change below -->
+<!--- do not change below --->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
