@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: English homepage translation
-# Copyright (C) 2004-2012 Carsten Gnörlich
+# Copyright (C) 2004-2010 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -14,11 +14,11 @@ begin_page();
 howto_headline("Getting information on images and error correction data", "Overview", "images/compare-icon.png");
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
 <table width="100%" cellspacing="5">
 <tr valign="top">
-<td class="w20p"><b>Task</b></td>
+<td width="20%"><b>Task</b></td>
 <td>
 Shows information on types and states of images and error correction files.
 </td>
@@ -29,9 +29,9 @@ Shows information on types and states of images and error correction files.
 <td colspan="2"><b>Required:</b><p></td>
 </tr>
 <tr>
- <td class="w150x" align="right">
-   <img src="../images/good-image.png" alt="Icon: Complete image" class="valignt">
-   <img src="../images/ecc.png" alt="Icon: Separate file with error correction data">
+ <td width="150px" align="right">
+   <img src="../images/good-image.png" align="top">
+   <img src="../images/ecc.png">
  </td>
 <td>
 An image file and optionally the error correction file for it.
@@ -39,7 +39,7 @@ An image file and optionally the error correction file for it.
 <tr><td> <pre> </pre> </td></tr>
 
 <tr>
-<td colspan="2"><b>What to do:</b><p></td>
+<td colspan="2"><b>What to do:<p></b></td>
 </tr>
 
 <tr>
@@ -58,7 +58,7 @@ An image file and optionally the error correction file for it.
 
 <a href="howtos51.php">Show the information...</a>
 
-<!-- do not change below -->
+<!--- do not change below --->
 <?php
 # end_page() adds the footer line and closes the HTML properly.
 end_page();
