@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: English homepage translation
-# Copyright (C) 2004-2012 Carsten Gnörlich
+# Copyright (C) 2004-2010 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -12,22 +12,21 @@ require("../include/dvdisaster.php");
 begin_page();
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
-<h3 class="top">Placeholder page</h3>
+<h3>Placeholder page</h3>
 
 This page has not yet been written.
 <pre> </pre>
 
 
-<span class="fs">
+<font size="-1">
 <i>Why does this documentation contain empty pages?</i><p>
 We need an empty placeholder page so that hyperlinks to this topic
 can already be placed into the documentation.
-</span>
 
 
-<!-- do not change below -->
+<!--- do not change below --->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
