@@ -1,7 +1,7 @@
 <?php
 
 # dvdisaster: Homepage layout functions
-# Copyright (C) 2007-2012 Carsten Gnörlich
+# Copyright (C) 2007-2010 Carsten Gnörlich
 
 require("version.php");
 
@@ -25,7 +25,7 @@ $script_lang = substr($script_dir, strlen($script_dir)-2, 2);
 # Needed to exatract some meaningful title text from the toc.php
 
 $toc_title_mode = 0;
-$toc_title_content = "unset title";
+$toc_title_content = "RBG";
 
 # Load the appropriate localization file
 
@@ -33,13 +33,6 @@ require("dict_" . $script_lang . ".php");
 
 # Locale wrappers for toc.php stubs
 
-function cs($msg) 
-{  global $toc_title_mode; 
-
-   if($toc_title_mode == 1) toc_title($msg, "cs"); 
-   else                     toc_link($msg, "cs"); 
-};
-
 function de($msg) 
 {  global $toc_title_mode; 
 
@@ -73,7 +66,6 @@ function start_html()
    global $create_feed;
    global $trans_atom_title;
 
-   echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n";
    echo "<html>\n";
    echo "<head>\n";
    echo " <meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n";
@@ -84,7 +76,7 @@ function start_html()
    $toc_title_mode = 0;
    echo " <link rel=\"stylesheet\" type=\"text/css\" href=\"../include/dvdisaster.css\">\n";
    if(!strcmp($script_name, "index"))
-   {  echo "<link rel=\"alternate\" type=\"application/atom+xml\" href=\"http://dvdisaster.net/$script_lang/feed/atom.xml\" title=\"$trans_atom_title\">\n";
+   {  echo "<link rel=\"alternate\" type=\"application/atom+xml\" href=\"http://dvdisaster.net/$script_lang/feed/atom.xml\" title=\"$trans_atom_title\" />\n";
       $create_feed=1;
    }
 
@@ -128,11 +120,11 @@ function begin_page()
 
    # Write the title header
 
-   echo "\n<!-- Title header -->\n";
+   echo "\n<!--- Title header --->\n";
    echo "<table width=\"100%\" cellpadding=\"0\" border=\"0\">\n";
    echo "  <tr>\n";
    echo "     <td align=\"left\">\n";
-   echo "       <span class=\"fxxl\"><b>dvdisaster</b></span>\n";
+   echo "       <font size=\"+3\"><b>dvdisaster</b></font>\n";
    if(!strcmp($have_experimental, "no"))
       echo "       <i>$trans_version $cooked_version</i>\n";
    else
@@ -140,9 +132,8 @@ function begin_page()
    if(!strcmp($mode, "local"))
    {  echo "  </td>\n";
       echo "  <td align=\"right\">\n";
-      echo "     <span class=\"fxxl\">&nbsp;</span><a href=\"http://dvdisaster.net/$script_lang/\">$trans_to_internet</a>\n";
-      lang_link("", "cs", 0); # TODO: This is a quick hack
-      lang_link("", "de", 0); # 
+      echo "     <font size=\"+3\">&nbsp;</font><a href=\"http://dvdisaster.net/$script_lang/\">$trans_to_internet</a>\n";
+      lang_link("", "de", 0); # TODO: This is a quick hack
       lang_link("", "en", 0); # to produce all locales for
       lang_link("", "ru", 0); # Windows. Do it better!
    }
@@ -152,11 +143,11 @@ function begin_page()
 
    # Write the language chooser depending on mode
 
-   echo "\n<!-- Language chooser or separator -->\n";
+   echo "\n<!--- Language chooser or separator --->\n";
    echo "<table width=\"100%\" cellpadding=\"0\" border=\"0\">\n";
 
-   echo "  <tr>\n";
-   echo "    <td colspan=\"2\" class=\"hsep\"></td>\n";
+   echo "  <tr bgcolor=\"#000000\">\n";
+   echo "    <td colspan=\"2\" width=\"100%\"><img width=1 height=1 alt=\"\"></td>\n";
    echo "  </tr>\n";
 
    if(strcmp($mode, "local"))
@@ -164,20 +155,21 @@ function begin_page()
       echo "  <tr>\n";
       echo "    <td align=\"left\"><a href=\"$project_at_hoster\">$trans_to_hoster</a></td>\n";
       echo "    <td align=\"right\">\n";
-      lang_link("&#268;esky", "cs", 1);
+#      lang_link("&#268;esky", "cs");
       lang_link("Deutsch", "de", 1);
       lang_link("English", "en", 1);
-      lang_link("Русский", "ru", 0);
+      lang_link("Russian", "ru", 0);
       echo "    </td>\n";
       echo "  </tr>\n";
-      echo "  <tr>\n";
-      echo "    <td colspan=\"2\" class=\"hsep\"></td>\n";
+      echo "  <tr bgcolor=\"#000000\">\n";
+      echo "    <td colspan=\"2\" width=\"100%\"><img width=1 height=1 alt=\"\"></td>\n";
       echo "  </tr>\n";
    }
 
    # Both modes get the separator 
 
-   echo "  <tr><td colspan=\"2\" style=\"height: 10px\">\n";
+   echo "  <tr><td colspan=\"2\" width=\"100%\" height=\"10\">\n";
+   echo "     <img width=1 height=1 alt=\"\">\n";
    echo "  </td></tr>\n";
    echo "</table>\n";
 
@@ -259,11 +251,11 @@ function toc_link($msg, $lang)
       # Draw the separator between sections (except for the first one)
 
       if(!$separator) $separator=1;
-      else echo "            <tr><td></td><td></td><td style=\"height:10px;\"></td></tr>\n";
+      else echo "            <tr><td></td><td></td><td height=\"10\"></td></tr>\n";
 
       if(!strcmp($toc_section, $script_name))
-	   echo "            <tr><td colspan=3><span class=\"fs\">$msg</span></td></tr>\n";
-      else echo "            <tr><td colspan=3><span class=\"fs\"><a href=\"$target\">$msg</a></span></td></tr>\n";
+	   echo "            <tr><td colspan=3><font size=\"-1\">$msg</font></td></tr>\n";
+      else echo "            <tr><td colspan=3><font size=\"-1\"><a href=\"$target\">$msg</a></font></td></tr>\n";
    }
 
    if(   !strcmp($toc_mode, "subsection") 
@@ -271,8 +263,8 @@ function toc_link($msg, $lang)
    {  $target=$toc_subsection . ".php";
 
       if(!strcmp($toc_subsection, $script_name))
-	   echo "            <tr><td style=\"width:1%; vertical-align:top;\">&middot;</td><td colspan=2><span class=\"fs\">$msg</span></td></tr>\n";
-      else echo "            <tr><td style=\"width:1%; vertical-align:top;\">&middot;</td><td colspan=2><span class=\"fs\"><a href=\"$target\">$msg</a></span></td></tr>\n";
+	   echo "            <tr><td valign=\"top\" width=\"1%\">&middot;</td><td colspan=2><font size=\"-1\">$msg</font></td></tr>\n";
+      else echo "            <tr><td valign=\"top\" width=\"1%\">&middot;</td><td colspan=2><font size=\"-1\"><a href=\"$target\">$msg</a></font></td></tr>\n";
    }
 
    # Using strlen($toc_section)+1 is inconvenient as it hardcodes the
@@ -283,8 +275,8 @@ function toc_link($msg, $lang)
    {  $target=$toc_subsubsection . ".php";
 
       if(!strcmp($toc_subsubsection, $script_name))
-	   echo "            <tr><td></td><td style=\"vertical-align:top; font-size:small;\">-</td><td><span class=\"fs\">${msg}</span></td></tr>\n";
-      else echo "        <tr><td></td><td style=\"vertical-align:top; font-size:small;\">-</td><td><span class=\"fs\"><a href=\"$target\">$msg</a></span></td></tr>\n";
+	   echo "            <tr><td valign=\"top\"></td><td>-</td><td><font size=\"-1\">${msg}</font></td></tr>\n";
+      else echo "        <tr><td valign=\"top\"></td><td>-</td><td><font size=\"-1\"><a href=\"$target\">$msg</a></font></td></tr>\n";
    }
 
 }
@@ -301,7 +293,7 @@ function news_headline($headline)
    global $doc_dir;
    global $trans_atom_title;
 
-   if(!$news_flash) echo "    <h3 class=\"top\">$headline</h3>\n";
+   if(!$news_flash) echo "    <h3>$headline</h3>\n";
 
    if($create_feed != 1) return;
 
@@ -366,10 +358,10 @@ function news_item($date, $headline, $body, $atom_tag, $atom_created, $atom_upda
    {  if($news_counter > $max_news_flash_items)
         return;
 
-      echo "          <span class=\"fs\">$date</span> <br>\n";
-      echo "          <span class=\"fs\">\n";
+      echo "          <font size=\"-1\">$date</font> <br>\n";
+      echo "          <font size=\"-1\">\n";
       echo "            <a href=\"news.php#item$atom_tag\">$headline</a>\n";
-      echo "          </span><p>\n";
+      echo "          </font><p>\n";
    }
    else
    {  
@@ -381,13 +373,13 @@ function news_item($date, $headline, $body, $atom_tag, $atom_created, $atom_upda
       echo "    </table>\n";
 ?>
     <table width="90%" cellpadding="0" cellspacing="0">
-       <tr>
-         <td class="hsep"></td>
+       <tr bgcolor="#000000" height=1>
+	 <td width="100%" height=1><img width=1 height=1 alt=""></td>
        </tr>
     </table>
     <table width="90%" cellpadding="0" cellspacing="0">
-       <tr style="height: 5px; width: 100%;">
-         <td></td>
+       <tr bgcolor="#ffffff" height=5>
+         <td width="100%" height=1><img width=1 height=1 alt=""></td>
        </tr>
     </table>
 <?php
@@ -414,20 +406,20 @@ function create_navigation()
    else $body_width = "77%";
 ?>
   
-<!-- Main body (Navigation, actual page content, optional news column) --> 
+<!--- Main body (Navigation, actual page content, optional news column) ---> 
 <table width="100%" cellspacing=0>
  <tr>
-  <!-- Navigation -->
-  <td style="background-color:#f0f0f0; vertical-align:top; width:20%;">
+  <!--- Navigation --->
+  <td bgcolor="#f0f0f0" valign="top" width="20%">
     <table width="100%" cellpadding="10">
       <tr>
         <td>
 <?php
-echo "         <span class=\"fs\"><b>$trans_contents</b></span>\n";
+echo "         <font size=\"-1\"><b>$trans_contents</b></font>\n";
 ?>
           <table width="100%" cellpadding="0" cellspacing="0">
-	    <tr>
-	      <td class="hsep"></td>
+	    <tr bgcolor="#000000">
+	      <td width="100%"><img width=1 height=1 alt=""></td>
 	    </tr>
 	  </table><p>
 
@@ -440,9 +432,9 @@ echo "         <span class=\"fs\"><b>$trans_contents</b></span>\n";
   </td>
   <td></td>
 
-  <!-- Actual page contents -->
+  <!--- Actual page contents --->
 <?php
-echo "  <td style=\"vertical-align:top; width:$body_width;\" rowspan=\"2\">\n";
+echo "  <td valign=\"top\" width=\"$body_width\" rowspan=\"2\">\n";
 
   # body contents must be appended here from calling page
 }
@@ -457,16 +449,18 @@ echo "  <td style=\"vertical-align:top; width:$body_width;\" rowspan=\"2\">\n";
 function end_page()
 {  global $script_file;
    global $trans_copyright;
+   global $trans_modified;
    global $trans_news;
    global $trans_fdl;
    global $trans_hosting;
+   global $modified_source;
    global $news_flash;
    global $news_counter;
    global $script_lang;
 
 # Close the body table
 
-  echo "  </td> <!-- end of page contents -->\n";
+  echo "  </td> <!--- end of page contents --->\n";
 
 # Insert news flash
 
@@ -474,17 +468,17 @@ function end_page()
   {
 ?>
 
-  <!-- news flash column -->
+  <!--- news flash column --->
   <td></td>
-  <td style="background-color:#e0e0ff; width:20%;" valign="top">
+  <td bgcolor="#e0e0ff" valign="top" width="20%">
     <table width="100%" cellpadding="10"><tr><td>
 <?php
-  echo "      <span class=\"fs\"><b>$trans_news</b></span>\n";
-  echo "      <a href=\"http://dvdisaster.net/$script_lang/feed/atom.xml\"><img src=\"../images/atom16.png\" alt=\"Subscribe to dvdisaster news feed\" class=\"noborder\"></a>\n";
+  echo "      <font size=\"-1\"><b>$trans_news</b></font>\n";
+  echo "      <a href=\"http://dvdisaster.net/$script_lang/feed/atom.xml\"><img src=\"../images/atom16.png\" border=></a>\n";
 ?>
       <table width="100%" cellpadding="0" cellspacing="0">
-         <tr>
-	   <td class="hsep"></td>
+         <tr bgcolor="#000000">
+	   <td width="100%"><img width=1 height=1 alt=""></td>
 	 </tr>
       </table><p>
       <table width="100%">
@@ -496,15 +490,15 @@ function end_page()
         </td></tr>
       </table>
     </table>
-  </td> <!-- end of news flash column-->
+  </td> <!--- end of news flash column--->
 <?php
   }
 # Reference to our hoster
 /*
  </tr>
  <tr valign="bottom">
-   <td style="background-color:#f0f0f0;" align="center">
- <?php echo "     <span class=\"fxs\">$trans_hosting</span><br>\n"; ?>
+   <td bgcolor="#f0f0f0" align="center">
+<?php echo "     <font size=\"-2\">$trans_hosting</font><br>\n"; ?>
       <img src="../images/mokelbude.png"
            width="125" height="37" border="0" alt="insider">
    </td>
@@ -515,42 +509,42 @@ function end_page()
 
  </tr>
 
-<!--
+<!---
  <tr valign="bottom">
-   <td style="background-color:#f0f0f0;">
+   <td bgcolor="#f0f0f0">
 <?php 
    $old_lang = strcmp($script_lang, "ru") ? $script_lang : "en";
-   echo "      <table cellpadding=\"10\"><tr><td><a href=\"http://dvdisaster.net/legacy/$old_lang/index.html\"><span class=\"fs\">$trans_old_version</span></a></td></tr></table>\n"; 
+   echo "      <table cellpadding=\"10\"><tr><td><a href=\"http://dvdisaster.net/legacy/$old_lang/index.html\"><font size=\"-1\">$trans_old_version</font></a></td></tr></table>\n"; 
 ?>
    </td>
    <td></td>
    <td></td>
  </tr>
--->
-</table> <!-- end of main body table -->
+--->
+</table> <!--- end of main body table --->
 
 <?php
 # Create the footer
 ?>
 
-<!-- Page footer -->
+<!--- Page footer --->
 <table width="100%" cellpadding="0" border="0">
- <tr><td colspan="2" style="width:100%; height:10px;"></td>
+ <tr><td colspan="2" width="100%" height="10"><img width=1 height=1 alt=""></td>
  </tr>
- <tr><td colspan="2" class="hsep"></td>
+ <tr bgcolor="#000000"><td colspan="2" width="100%"><img width=1 height=1 alt=""></td>
  </tr>
  <tr>
   <td align="center">
-   <span class="fs">
+   <font size="-1">
 <?php
    echo "     <i> $trans_copyright<br>\n";
    echo "         $trans_fdl\n";
 ?>
     </i>
-   </span>
+   </font>
   </td>
  </tr>
- <tr><td colspan="2" class="hsep"></td>
+ <tr bgcolor="#000000"><td colspan="2" width="100%"><img width=1 height=1 alt=""></td>
  </tr>
 </table>
 </body>
@@ -564,9 +558,9 @@ function end_page()
 
 function howto_headline($headline, $subtitle, $image)
 {
-   echo "<table width=\"100%\" style=\"background-color:#f0f0f0;\">\n";
-   echo "<tr><td><span class=\"fl\"><b>$headline</b></span></td>\n";
-   echo "<td rowspan=\"2\" align=\"right\"><img src=\"$image\" alt=\"\"></td></tr>\n";
+   echo "<table width=\"100%\" bgcolor=\"#f0f0f0\">\n";
+   echo "<tr><td><font size=\"+1\"><b>$headline</b></font></td>\n";
+   echo "<td rowspan=\"2\" align=\"right\"><img src=\"$image\"></td></tr>\n";
    echo "<tr><td><i>$subtitle</i></td></tr>\n";
    echo "</table><p>\n";
 }
