@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: Russian homepage translation
-# Copyright (C) 2007-2012 Igor Gorbounov
+# Copyright (C) 2007-2010 Igor Gorbounov
 #
 # UTF-8 trigger: äöüß 
 #
@@ -14,29 +14,16 @@ begin_page();
 $show_all=$_GET["showall"];
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
-<h3 class="top">Скачать dvdisaster</h3>
-
-<!--
-<table width="100%">
-<tr>
-<td>dvdisaster имеется для <a href="download10.php">последних версий</a>
-операционных систем FreeBSD, GNU/Linux, Mac OS X(Darwin), NetBSD 
-и Windows. Он предоставляется как
-<a href="http://www.germany.fsfeurope.org/documents/freesoftware.en.html">свободное программное обеспечение</a> 
-под лицензией <a href="http://www.gnu.org/licenses/gpl-3.0.txt">GNU General Public License v3</a>.</td>
-<td class="w127x" valign="top"><img src="../images/gplv3-127x51.png" alt="GPLv3 logo" width="127"></td>
-</tr>
-</table>
--->
+<h3>Скачать dvdisaster</h3>
 
 dvdisaster имеется для <a href="download10.php">последних версий</a>
 операционных систем FreeBSD, GNU/Linux, Mac OS X(Darwin), NetBSD 
 и Windows. Он предоставляется как
 <a href="http://www.germany.fsfeurope.org/documents/freesoftware.en.html">свободное программное обеспечение</a> 
-под лицензией <a href="http://www.gnu.org/licenses/gpl-2.0.txt">GNU General Public License v2</a>.
-<p>
+под лицензией <a href="http://dvdisaster.cvs.sourceforge.net/dvdisaster/dvdisaster/COPYING?view=markup">GNU General Public License v2</a><a href="#gpl3"><sup>*)</sup></a>.<p>
+
 Скачивать исходные тексты или двоичную версию можно из приведенного ниже списка.
 <a href="download20.php">Цифровая подпись</a> предоставляется для подтверждения того, что
 пакеты находятся в своем первоначальном состоянии.<p>
@@ -69,51 +56,39 @@ if(!strcmp($have_experimental, "yes"))
 <a name="download"></a>
 
 <table class="download" cellpadding="0" cellspacing="5">
-<tr><td><b>dvdisaster-0.72</b></td><td align="right">07 Apr 2012</td></tr>
-<tr><td colspan="2" class="hsep"></td></tr>
+<tr><td><b>dvdisaster-0.72</b></td><td align="right">07 Nov 2010</td></tr>
+<tr bgcolor="#000000"><td colspan="2"><img width=1 height=1 alt=""></td></tr>
 <tr><td colspan="2">
   <table>
     <tr><td align="right">&nbsp;&nbsp;Исходные тексты для всех операционных систем:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.4.tar.bz2">dvdisaster-0.72.4.tar.bz2</a></td></tr>
+        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.tar.bz2">dvdisaster-0.72.2.tar.bz2</a></td></tr>
     <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.4.tar.bz2.gpg">dvdisaster-0.72.4.tar.bz2.gpg</a></td></tr>
+        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.tar.bz2.gpg">dvdisaster-0.72.2.tar.bz2.gpg</a></td></tr>
 
 <?php
-if($mode == "www")
-    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>4eb09c1aa3cdbc1dafdb075148fb471d</td></tr>";
+if($mode == "www");
+    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>312bceef3bf9c0754cf633ed3b12eb71</td></tr>";
 ?>
-    <tr><td><pre> </pre></td><td></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
-
-    <tr><td align="right">&nbsp;&nbsp;Исходные тексты для всех операционных систем:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.3.tar.bz2">dvdisaster-0.72.3.tar.bz2</a></td></tr>
+    <tr><td align="right">Двоичная версия для Mac OS X 10.5 / x86:&nbsp;</td>
+        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.app.zip">dvdisaster-0.72.2.app.zip</a>&nbsp;--&nbsp;сначала прочитайте эти <a href="download30.php#mac">советы</a></td></tr>
     <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.3.tar.bz2.gpg">dvdisaster-0.72.3.tar.bz2.gpg</a></td></tr>
+        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.app.zip.gpg">dvdisaster-0.72.2.app.zip.gpg</a></td></tr>
 
 <?php
-if($mode == "www")
-    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>4eb09c1aa3cdbc1dafdb075148fb471d</td></tr>";
+if($mode == "www");
+    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>52243c1fafb9d2e496b6eb318c3e534f</td></tr>";
 ?>
-    <tr><td colspan="2" class="esep"></td></tr>
-
-    <tr><td align="right">Двоичная версия для Mac OS X 10.6 / x86:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.3.app.zip">dvdisaster-0.72.3.app.zip</a>&nbsp;--&nbsp;сначала прочитайте эти <a href="download30.php#mac">советы</a></td></tr>
-    <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.3.app.zip.gpg">dvdisaster-0.72.3.app.zip.gpg</a></td></tr>
-
-<?php
-if($mode == "www")
-    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>38389bbbeb0d259a3f0a8df89b363f72</td></tr>";
-?>
-    <tr><td colspan="2" class="esep"></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
     <tr><td align="right">Двоичная версия для Windows:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.3-setup.exe">dvdisaster-0.72.3-setup.exe</a></td></tr>
+        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2-setup.exe">dvdisaster-0.72.2-setup.exe</a></td></tr>
     <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.3-setup.exe.gpg">dvdisaster-0.72.3-setup.exe.gpg</a></td></tr>
+        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2-setup.exe.gpg">dvdisaster-0.72.2-setup.exe.gpg</a></td></tr>
 <?php
-if($mode == "www")
-    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>b6861ba1e8de6d91a2da5342a14870e0</td></tr>";
+if($mode == "www");
+    echo "<tr><td align=\"right\">MD5 checksum:&nbsp;</td><td>f80258d27354061fd9e28850ec4701a6</td></tr>";
 ?>
     <tr><td colspan="2"> </td></tr>
 
@@ -127,30 +102,6 @@ if($mode == "www")
 ?> 
     <tr><td colspan="2"><a href="download.php?showall=0#download">Hide older releases in the 0.72 version branch</a></td></tr>
 
-   <tr><td colspan="2"> </td></tr>
-   <tr><td></td><td>Version 0.72.2</td></tr>
-    <tr><td align="right">&nbsp;&nbsp;Исходные тексты для всех операционных систем:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.tar.bz2">dvdisaster-0.72.2.tar.bz2</a></td></tr>
-    <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.tar.bz2.gpg">dvdisaster-0.72.2.tar.bz2.gpg</a></td></tr>
-
-     <tr><td align="right">MD5 checksum:&nbsp;</td><td>312bceef3bf9c0754cf633ed3b12eb71</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
-
-    <tr><td align="right">Двоичная версия для Mac OS X 10.5 / x86:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.app.zip">dvdisaster-0.72.2.app.zip</a>&nbsp;--&nbsp;сначала прочитайте эти <a href="download30.php#mac">советы</a></td></tr>
-    <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2.app.zip.gpg">dvdisaster-0.72.2.app.zip.gpg</a></td></tr>
-
-    <tr><td align="right">MD5 checksum:&nbsp;</td><td>52243c1fafb9d2e496b6eb318c3e534f</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
-
-    <tr><td align="right">Двоичная версия для Windows:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2-setup.exe">dvdisaster-0.72.2-setup.exe</a></td></tr>
-    <tr><td align="right">Цифровая подпись:&nbsp;</td>
-        <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.2-setup.exe.gpg">dvdisaster-0.72.2-setup.exe.gpg</a></td></tr>
-    <tr><td align="right">MD5 checksum:&nbsp;</td><td>f80258d27354061fd9e28850ec4701a6</td></tr>
-
    <tr><td colspan="2"> </td></tr>
    <tr><td></td><td>Version 0.72.1</td></tr>
     <tr><td align="right">&nbsp;&nbsp;Исходные тексты для всех операционных систем:&nbsp;</td>
@@ -159,7 +110,7 @@ if($mode == "www")
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.1.tar.bz2.gpg">dvdisaster-0.72.1.tar.bz2.gpg</a></td></tr>
     <tr><td align="right">MD5 checksum:&nbsp;</td>
         <td>4da96566bc003be93d9dfb0109b4aa1d</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
     <tr><td align="right">Двоичная версия для Mac OS X 10.5 / x86:&nbsp;</td>
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.1.app.zip">dvdisaster-0.72.1.app.zip</a>&nbsp;--&nbsp;сначала прочитайте эти <a href="download30.php#mac">советы</a></td></tr>
@@ -167,7 +118,7 @@ if($mode == "www")
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.1.app.zip.gpg">dvdisaster-0.72.1.app.zip.gpg</a></td></tr>
     <tr><td align="right">MD5 checksum:&nbsp;</td>
         <td>924b5677f69473b6b87991e01779a541</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
     <tr><td align="right">Двоичная версия для Windows:&nbsp;</td>
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.1-setup.exe">dvdisaster-0.72.1-setup.exe</a></td></tr>
@@ -184,7 +135,7 @@ if($mode == "www")
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.tar.bz2.gpg">dvdisaster-0.72.tar.bz2.gpg</a></td></tr>
     <tr><td align="right">MD5 checksum:&nbsp;</td>
         <td>efa35607d91412a7ff185722f270fb8a</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
     <tr><td align="right">Двоичная версия для Mac OS X 10.5 / x86:&nbsp;</td>
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.app.zip">dvdisaster-0.72.app.zip</a>&nbsp;--&nbsp;сначала прочитайте эти <a href="download30.php#mac">советы</a></td></tr>
@@ -192,7 +143,7 @@ if($mode == "www")
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72.app.zip.gpg">dvdisaster-0.72.app.zip.gpg</a></td></tr>
     <tr><td align="right">MD5 checksum:&nbsp;</td>
         <td>1f28385b2b6d64b664fd416eb4c85e80</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
     <tr><td align="right">Двоичная версия для Windows:&nbsp;</td>
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.72-setup.exe">dvdisaster-0.72-setup.exe</a></td></tr>
@@ -206,7 +157,7 @@ if($mode == "www")
 ?>
   </table>
 </td></tr>
-<tr><td colspan="2" class="hsep"></td></tr>
+<tr bgcolor="#000000"><td colspan="2"><img width=1 height=1 alt=""></td></tr>
 <tr><td colspan="2">
 Наиболее важные изменения в этой версии:<p>
 <ul>
@@ -225,14 +176,6 @@ if($mode == "www")
 
 <b>Исправления</b> (небольшие изменения после версии 0.72; вышеприведенные файлы были обновлены):<p>
 
-<b>0.72 pl4</b> Updated for new versions and programming libraries of
-GNU/Linux, FreeBSD and NetBSD. (07-Apr-2012)<p>
-
-<b>0.72 pl3</b> Fixed a problem with the "Verify" function when
- working with RS01 error correction files larger than 2GB.
-Thanks to Volodymyr Bychkoviak for reporting the problem and
-sending a fix. (05-Oct-2011)<p>
-
 <b>0.72 pl2</b> 
 This version introduces a workaround which prevents parallel SCSI
 adapters from freezing under Linux. 
@@ -272,7 +215,7 @@ please try getting dvdisaster via
 
 <table class="download" cellpadding="0" cellspacing="5">
 <tr><td><b>dvdisaster-0.70</b></td><td align="right">04 марта 2008</td></tr>
-<tr><td colspan="2" class="hsep"></td></tr>
+<tr bgcolor="#000000"><td colspan="2"><img width=1 height=1 alt=""></td></tr>
 <tr><td colspan="2">
   <table>
     <tr><td align="right">&nbsp;&nbsp;Исходный текст для всех операционных систем:&nbsp;</td>
@@ -281,7 +224,7 @@ please try getting dvdisaster via
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.70.6.tar.bz2.gpg">dvdisaster-0.70.6.tar.bz2.gpg</a></td></tr>
     <tr><td align="right">MD5 checksum:&nbsp;</td>
         <td>c6d2215d7dd582475b19593dfa4fbdc2</td></tr>
-    <tr><td colspan="2" class="esep"></td></tr>
+    <tr><td colspan="2"><img width=1 height=3</td></tr>
 
     <tr><td align="right">Двоичный пакет для Windows:&nbsp;</td>
         <td><a href="http://dvdisaster.net/downloads/dvdisaster-0.70.6-setup.exe">dvdisaster-0.70.6-setup.exe</a></td></tr>
@@ -292,7 +235,7 @@ please try getting dvdisaster via
 
   </table>
 </td></tr>
-<tr><td colspan="2" class="hsep"></td></tr>
+<tr bgcolor="#000000"><td colspan="2"><img width=1 height=1 alt=""></td></tr>
 <tr><td colspan="2">
 Метод коррекции ошибок RS02
 полностью поддерживается в графическом интерфейсе. Образы, созданные
@@ -347,7 +290,7 @@ please try getting dvdisaster via
 <li><a href="http://dvdisaster.cvs.sourceforge.net/dvdisaster/dvdisaster/README?view=markup">README</a> - план развития из архива исходных текстов.</li>
 </ul>
 
-<!-- do not change below -->
+<!--- do not change below --->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
