@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: Russian homepage translation
-# Copyright (C) 2007-2012 Igor Gorbounov
+# Copyright (C) 2007-2010 Igor Gorbounov
 #
 # UTF-8 trigger: äöüß 
 #
@@ -14,7 +14,7 @@ begin_page();
 howto_headline("Поиск ошибок на носителях", "Обзор", "images/scan-icon.png");
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
 <table width="100%" cellspacing="5">
 <tr>
@@ -29,15 +29,15 @@ howto_headline("Поиск ошибок на носителях", "Обзор",
  <td colspan="2"><b>Требуется:</b></td>
 </tr>
 <tr>
- <td width="150px"><img src="../images/good-cd.png" alt="Icon: Good medium (without read errors)" class="valignt">
-   &nbsp; <img src="../images/bad-cd.png" alt="Icon: Damaged medium (partially unreadable)" class="valignt"></td>
+ <td width="150px"><img src="../images/good-cd.png" align="top">
+   &nbsp; <img src="../images/bad-cd.png" align="top"></td>
 <td>
    Носитель в любом состоянии (хорошем или с ошибками чтения).
 </td>
 </tr>
 
 <tr>
- <td><img src="../images/ecc.png" alt="Icon: Separate file with error correction data"></td>
+ <td><img src="../images/ecc.png"></td>
  <td>Если имеются данные для исправления ошибок, выполняются дополнительные тесты.
 Но поиск ошибок работает и без данных для исправления ошибок.</td>
 </tr>
@@ -56,9 +56,9 @@ howto_headline("Поиск ошибок на носителях", "Обзор",
 <tr><td> <pre> </pre> </td></tr>
 
 <tr valign="top">
- <td><b>Соответствующие функции:</b></td>
- <td><a href="howtos30.php">Чтение поврежденных носителей</a> и<br>
-     <a href="howtos40.php">Восстановление образов</a>.</td>
+ <td><b>Соответствующие функции:<p></td>
+ <td><a href="howtos30.html">Чтение поврежденных носителей</a> и<br>
+     <a href="howtos40.html">Восстановление образов</a>.</td>
  </tr>
 </table><p>
 
@@ -67,7 +67,7 @@ howto_headline("Поиск ошибок на носителях", "Обзор",
 <a href="howtos11.php">Конфигурирование основных настроек...</a>
 
 
-<!-- do not change below -->
+<!--- do not change below --->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
