@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: Russian homepage translation
-# Copyright (C) 2007-2012 Igor Gorbounov
+# Copyright (C) 2007-2010 Igor Gorbounov
 #
 # UTF-8 trigger: äöüß 
 #
@@ -12,9 +12,9 @@ require("../include/dvdisaster.php");
 begin_page();
 ?>
 
-<!-- Insert actual page content below -->
+<!--- Insert actual page content below --->
 
-<h3 class="top"><a name="top">Технические вопросы</a></h3>
+<h3><a name="top">Технические вопросы</a></h3>
 
 <a href="#nls">2.1 На какие языки переведена программа?</a><p>
 <a href="#media">2.2 Какие типы носителей поддерживаются?</a><p>
@@ -27,7 +27,7 @@ begin_page();
 Текущая версия dvdisaster содержит экранные тексты на следующих языках:<p>
 
 <table>
-<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Чешский</td><td>--</td><td>полный</td></tr>
+<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Чешский</td><td>--</td><td>до версии 0.66</td></tr>
 <tr><td></td><td>Английский</td><td>--</td><td>полный</td></tr>
 <tr><td>&nbsp;&nbsp;&nbsp;</td><td>Немецкий</td><td>--</td><td>полный</td></tr>
 <tr><td>&nbsp;&nbsp;&nbsp;</td><td>Итальянский</td><td>--</td><td>до версии 0.65</td></tr>
@@ -51,7 +51,7 @@ dvdisaster автоматически получает языковые наст
 
 <tt>export OUTPUT_CHARSET=iso-8859-1</tt> (X11, XTerm)
 
-<div class="talignr"><a href="#top">&uarr;</a></div>
+<div align=right><a href="#top">&uarr;</a></div>
 
 
 <b><a name="media">2.2 Какие типы носителей поддерживаются?</a></b><p>
@@ -97,7 +97,7 @@ dvdisaster поддерживает (пере-)записываемые CD и DV
 <b>Непригодные типы</b> (образ нельзя извлечь):<p>
 DVD-ROM (печатаемые DVD), CD-Audio и CD-Video.
 
-<div class="talignr"><a href="#top">&uarr;</a></div><p>
+<div align=right><a href="#top">&uarr;</a></div><p>
 
 
 <b><a name="filesystem">2.3 Какие файловые системы поддерживаются?</a></b><p>
@@ -109,9 +109,9 @@ dvdisaster работает исключительно на уровне обр
 Поскольку dvdisaster как не знает, так и не использует структуру файловой системы,
 он не может исправлять логические ошибки на уровне файловой системы.
 Он не может восстанавливать потерянные или удаленные файлы.
-<div class="talignr"><a href="#top">&uarr;</a></div><p>
+<div align=right><a href="#top">&uarr;</a></div><p>
 
-<!-- do not change below -->
+<!--- do not change below --->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
