@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -42,6 +42,10 @@ void register_rs02(void)
    method->fix     = RS02Fix;
    method->verify  = RS02Verify;
 
+   /*** Linkage to rs01-common.c */
+
+   method->recognizeEccImage = RS02Recognize;
+
    /*** Linkage to rs02-window.c */
 
    method->createCreateWindow = CreateRS02EncWindow;
