@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -478,29 +478,12 @@ GtkWidget* ShowTextfile(char *title, char *explanation, char *file,
 	 size = strlen(buf);
       }
       else
-      {  FILE *fptr = portable_fopen(path, "rb");
-	 size_t bytes_read;
+      {  FILE *file = portable_fopen(path, "rb");
 
-	 if(!fptr)
-	 {  char *trans = _utf("File\n%s\nnot accessible");
-
-	    buf = g_strdup_printf(trans, file);
-	    size = strlen(buf);
-	 }
-	 else
-	 {  buf = g_malloc(size);
-	    bytes_read = fread(buf, 1, size, fptr);
-	    fclose(fptr);
-	    g_free(path);
-
-	    if(bytes_read < size)
-	    {  char *trans = _utf("\n<- Error: Text file truncated here");
-
- 	       size = bytes_read + strlen(trans);
-	       buf = realloc(buf, size+1);
-	       strcpy(&buf[bytes_read], trans);
-	    }
-	 }
+	 buf = g_malloc(size);
+	 fread(buf, size, 1, file);
+	 fclose(file);
+	 g_free(path);
       }
    }
    else 
@@ -723,11 +706,11 @@ void AboutDialog()
 
 #ifdef MODIFIED_SOURCE
    AboutTextWithLink(vbox, 
-		     _("Modified version Copyright 2012 (please fill in - [directions])\n"
-		       "Copyright 2004-2012 Carsten Gnoerlich"),
+		     _("Modified version Copyright 2010 (please fill in - [directions])\n"
+		       "Copyright 2004-2010 Carsten Gnoerlich"),
 		     "MODIFYING");
 #else
-   AboutText(vbox, _("Copyright 2004-2012 Carsten Gnoerlich"));
+   AboutText(vbox, _("Copyright 2004-2010 Carsten Gnoerlich"));
 #endif
 
    sep = gtk_hseparator_new();
@@ -761,6 +744,10 @@ void AboutDialog()
    }
 
    AboutText(vbox, _("\ne-mail: carsten@dvdisaster.org   -or-   cgnoerlich@fsfe.org")); 
+
+#ifdef SYS_DARWIN
+   AboutText(vbox, _("\nDarwin port (Mac OS X): Julian Einwag &lt;julian@einwag.de&gt;")); 
+#endif
 #ifdef SYS_NETBSD
    AboutText(vbox, _("\nNetBSD port: Sergey Svishchev &lt;svs@ropnet.ru&gt;")); 
 #endif
