@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -21,7 +21,7 @@
 
 #define _GNU_SOURCE
 
-#if !defined(SYS_FREEBSD)   /* FreeBSD declares malloc() in stdlib.h */
+#if !defined(SYS_FREEBSD) && !defined(SYS_DARWIN)   /* FreeBSD declares malloc() in stdlib.h */
  #include <malloc.h>
 #endif
 #include <stdio.h>
@@ -30,6 +30,7 @@
 
 #include <glib.h>
 #include <glib/gprintf.h>
+#include <glib/gstrfuncs.h>
 
 /*
  * We're not pulling in dvdisaster.h on purpose...
@@ -168,7 +169,7 @@ static void print_ptr(memchunk *mc, int size)
 static void print_ptrs(char *msg)
 {  int bucket,i,n=0;
 
-   g_printf("%s", msg);
+   g_printf(msg);
 
    for(bucket=0; bucket<64; bucket++)
       for(i=0; i<phCnt[bucket]; i++)
