@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -216,10 +216,23 @@ void RS01Create(Method *self)
 
    /*** Test the image file and create the CRC sums */
 
-   /* Explicitly unlinking the ecc file removes superflous segments
-      in FAT mode if the ecc file already existed. */
+   /* Get rid of old ecc file (if any exists) */
+
+   if(LargeStat(Closure->eccName, &n))
+   {  
+      if(ConfirmEccDeletion(Closure->eccName))
+	 LargeUnlink(Closure->eccName);
+      else
+      {  SetLabelText(GTK_LABEL(ec->wl->encFootline),
+		      _("<span %s>Aborted to keep existing ecc file.</span>"),
+		      Closure->redMarkup); 
+	 ec->earlyTermination = FALSE;
+	 goto terminate;
+      }
+   }
+
+   /* Open new ecc file */
 
-   LargeUnlink(Closure->eccName); 
    ei = ec->ei = OpenEccFile(WRITEABLE_ECC);
    ii = ec->ii = OpenImageFile(NULL, READABLE_IMAGE);
 
@@ -336,7 +349,7 @@ void RS01Create(Method *self)
 	version 0.40.7 due to a bug in the version processing code.
 	So ecc files tagged with -devel or -rc status will not work with prior
 	versions. But they are experimental version available only through CVS, 
-	so this issue is not a big as it appears.
+	so this issue is not as big as it appears.
       - Version 0.66 records the inLast value in the ecc file to facilitate
         processing non-image files. Previous versions do not use this field
 	and may round up file length to the next multiple of 2048 when doing
@@ -970,8 +983,7 @@ void RS01Create(Method *self)
 
       SetLabelText(GTK_LABEL(wl->encFootline), 
 		   _("The error correction file has been successfully created.\n"
-		     "Make sure to keep this file on a reliable medium."),
-		   Closure->eccName); 
+		     "Make sure to keep this file on a reliable medium.")); 
    }
 
    /*** If the --unlink option or respective GUI switch is set, 
