@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -29,7 +29,20 @@
 
 static void redraw_curve(RS01Widgets*);
 static void update_geometry(RS01Widgets*);
+
+/* Protected widget access */
       
+static void activate_toggle_button(GtkToggleButton *toggle, int state)
+{  if(toggle) gtk_toggle_button_set_active(toggle, state);
+}
+
+static void set_range_value(GtkRange *range, int value)
+{  if(range) gtk_range_set_value(range, value);
+}
+
+static void set_spin_button_value(GtkSpinButton *spin, int value)
+{  if(spin) gtk_spin_button_set_value(spin, value);
+}
 
 /***
  *** Encoding window
@@ -413,9 +426,13 @@ enum
    PREF_ECC_SIZE = 2
 };
 
+#ifdef HAVE_32BIT
+static int cache_size[] = { 8, 16, 32, 64, 96, 128, 192, 256, 384, 512, 768, 
+			    1024, 1536 };
+#else
 static int cache_size[] = { 8, 16, 32, 64, 96, 128, 192, 256, 384, 512, 768, 
 			    1024, 1536, 2048, 2560, 3072, 4096, 5120, 6144, 7168, 8192 };
-//			    11264, 15360, 23552, 31744, 48128, 64512 };
+#endif
 
 static gchar* format_cb(GtkScale *scale, gdouble value, gpointer data)
 {  int nroots = value;
@@ -463,8 +480,10 @@ static void nroots_cb(GtkWidget *widget, gpointer data)
    Closure->redundancy = g_strdup_printf("%d", value);
 
    if(widget == wl->redundancyScaleA)
-        gtk_range_set_value(GTK_RANGE(wl->redundancyScaleB), value);
-   else gtk_range_set_value(GTK_RANGE(wl->redundancyScaleA), value);
+        set_range_value(GTK_RANGE(wl->redundancyScaleB), value);
+   else set_range_value(GTK_RANGE(wl->redundancyScaleA), value);
+
+   UpdateMethodPreferences();
 }
 
 static void ecc_size_cb(GtkWidget *widget, gpointer data)
@@ -479,13 +498,14 @@ static void ecc_size_cb(GtkWidget *widget, gpointer data)
         gtk_spin_button_set_value(GTK_SPIN_BUTTON(wl->redundancySpinB), atoi(Closure->redundancy));
    else gtk_spin_button_set_value(GTK_SPIN_BUTTON(wl->redundancySpinA), atoi(Closure->redundancy));
 
+   UpdateMethodPreferences();
 }
 
 static void toggle_cb(GtkWidget *widget, gpointer data)
 {  Method *method = (Method*)data;
    RS01Widgets *wl = (RS01Widgets*)method->widgetList;
    int state  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
-
+      
    if(state == TRUE)
    {  if(widget == wl->radio3A || widget == wl->radio3B)
       {  gtk_widget_set_sensitive(wl->redundancyScaleA, TRUE);
@@ -512,8 +532,8 @@ static void toggle_cb(GtkWidget *widget, gpointer data)
       if(   widget == wl->radio1A  /* Normal */
 	 || widget == wl->radio1B)
       {  
-         gtk_range_set_value(GTK_RANGE(wl->redundancyScaleA), 32);
-         gtk_range_set_value(GTK_RANGE(wl->redundancyScaleB), 32);
+         set_range_value(GTK_RANGE(wl->redundancyScaleA), 32);
+         set_range_value(GTK_RANGE(wl->redundancyScaleB), 32);
 
 	 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wl->radio1A), TRUE);
 	 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wl->radio1B), TRUE);
@@ -525,8 +545,8 @@ static void toggle_cb(GtkWidget *widget, gpointer data)
       if(   widget == wl->radio2A  /* High */
 	 || widget == wl->radio2B)
       {  
-         gtk_range_set_value(GTK_RANGE(wl->redundancyScaleA), 64);
-         gtk_range_set_value(GTK_RANGE(wl->redundancyScaleB), 64);
+         set_range_value(GTK_RANGE(wl->redundancyScaleA), 64);
+         set_range_value(GTK_RANGE(wl->redundancyScaleB), 64);
 
 	 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wl->radio2A), TRUE);
 	 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wl->radio2B), TRUE);
@@ -556,6 +576,8 @@ static void toggle_cb(GtkWidget *widget, gpointer data)
 	 if(Closure->redundancy) g_free(Closure->redundancy);
 	 Closure->redundancy = g_strdup_printf("%dm", space);
       }
+
+      UpdateMethodPreferences();
    }
 }
 
@@ -563,12 +585,72 @@ void ResetRS01PrefsPage(Method *method)
 {  RS01Widgets *wl = (RS01Widgets*)method->widgetList;
    int index;
 
+   /* Redundancy selection */
+
+   if(Closure->redundancy)
+   {  
+      if(!strcmp(Closure->redundancy, "normal"))
+      {  if(wl->radio1A && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wl->radio1A)) == FALSE)
+	 {  activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio1A), TRUE);
+	    activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio1B), TRUE);
+	 }
+      }
+      else if(!strcmp(Closure->redundancy, "high"))
+      {  if(wl->radio2A && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wl->radio2A)) == FALSE)
+	 {  activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio2A), TRUE);
+	    activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio2B), TRUE);
+	 }
+      }
+      else
+      {  int last = strlen(Closure->redundancy)-1;
+
+         if(Closure->redundancy[last] == 'm')
+	 {  if(wl->redundancySpinA)
+	    {  int old = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(wl->redundancySpinA));
+	       int new;
+
+	       Closure->redundancy[last] = 0;
+	       new = atoi(Closure->redundancy);
+	       Closure->redundancy[last] = 'm';
+
+	       if(new != old)
+	       {  set_spin_button_value(GTK_SPIN_BUTTON(wl->redundancySpinA), new);
+		  set_spin_button_value(GTK_SPIN_BUTTON(wl->redundancySpinB), new);
+	       }
+
+	       if(wl->radio4A && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wl->radio4A)) == FALSE)
+	       {  activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio4A), TRUE);
+		  activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio4B), TRUE);
+	       }
+	    }
+	 }
+	 else
+	 {  if(wl->redundancyScaleA)
+	    {  int old = gtk_range_get_value(GTK_RANGE(wl->redundancyScaleA));
+	       int new = atoi(Closure->redundancy);
+
+	       if(new != old)
+	       {  set_range_value(GTK_RANGE(wl->redundancyScaleA), new);
+	          set_range_value(GTK_RANGE(wl->redundancyScaleB), new);
+	       }
+
+	       if(wl->radio3A && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wl->radio3A)) == FALSE)
+	       {  activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio3A), TRUE);
+		  activate_toggle_button(GTK_TOGGLE_BUTTON(wl->radio3B), TRUE);
+	       }
+	    }
+	 }
+      }
+   }
+
+   /* Memory caching */
+
    for(index = 0; index < sizeof(cache_size)/sizeof(int); index++)
      if(cache_size[index] > Closure->cacheMB)
        break;
 
-   gtk_range_set_value(GTK_RANGE(wl->cacheScaleA), index > 0 ? index-1 : index);
-   gtk_range_set_value(GTK_RANGE(wl->cacheScaleB), index > 0 ? index-1 : index);
+   set_range_value(GTK_RANGE(wl->cacheScaleA), index > 0 ? index-1 : index);
+   set_range_value(GTK_RANGE(wl->cacheScaleB), index > 0 ? index-1 : index);
 }
 
 void CreateRS01PrefsPage(Method *method, GtkWidget *parent)
@@ -763,6 +845,7 @@ void CreateRS01PrefsPage(Method *method, GtkWidget *parent)
 	 {  Closure->redundancy[last] = 0;
 	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(wl->redundancySpinA), atoi(Closure->redundancy));
 	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(wl->redundancySpinB), atoi(Closure->redundancy));
+	    Closure->redundancy[last] = 'm';
 	    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wl->radio4A), TRUE);
 	    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wl->radio4B), TRUE);
 	 }
