@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -158,6 +158,11 @@ void RS02Create(Method*);
 
 void RS02Fix(Method*);
 
+/* rs02-recognize.c */
+
+EccHeader* FindRS02HeaderInImage(LargeFile*);
+int  RS02Recognize(Method*, LargeFile*);
+
 /* rs02-window.c */
 
 void RS02AddFixValues(RS02Widgets*, int, int);
