@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -157,7 +157,7 @@ static int try_fallback_type_check(DeviceHandle *dh)
 {  AlignedBuffer *ab;
    Sense *sense = &dh->sense;
    unsigned char cmd[MAX_CDB_SIZE];
-   unsigned int length;
+   int length;
 
    Verbose("# *** try_fallback_type_check(%s) ***\n", dh->devinfo);
 
@@ -190,8 +190,6 @@ static int try_fallback_type_check(DeviceHandle *dh)
 
    length = ab->buf[0]<<8 | ab->buf[1];
    length += 2;
-   length_align(&length);
-
    if(length != 4100) /* not a BD */
    {  Verbose("# allocation length = %d != 4100 -> not a BD type medium.\n", length);
       goto try_dvd;
@@ -479,7 +477,6 @@ static int query_cd(DeviceHandle *dh, int probe_only)
    length = buf[0]<<8 | buf[1];
    length += 2  ;  /* MMC3: "Disc information length excludes itself" */
    length_align(&length);
-
    Verbose("#CD: size returned is %d\n", length);
 
    if(length>1024) /* don't let the drive hack us using a buffer overflow ;-) */
@@ -538,7 +535,6 @@ static int query_cd(DeviceHandle *dh, int probe_only)
    length = buf[0]<<8 | buf[1];
    length += 2;    /* MMC3: "Disc information length excludes itself" */
    length_align(&length);
-
    Verbose("#CD: size returned is %d\n", length);
 
    if(length < 15)
@@ -554,7 +550,9 @@ static int query_cd(DeviceHandle *dh, int probe_only)
       return FALSE;
    }
 
+#if 0
    length = 16;  /* Works around Windows (and possibly other OS) driver issues */
+#endif
 
    memset(cmd, 0, MAX_CDB_SIZE);
    cmd[0] = 0x43;  /* READ TOC/PMA/ATIP */
@@ -975,7 +973,6 @@ static int query_bd(DeviceHandle *dh, int probe_only)
    length = buf[0]<<8 | buf[1];
    length += 2;
    length_align(&length);
-
    Verbose("#BD: disc structure query succeeded, length %d bytes\n", length);
 
    /* Do the real query */
@@ -1082,6 +1079,7 @@ static int query_type(DeviceHandle *dh, int probe_only)
    Verbose("# trying READ DISC INFORMATION for size\n");
    if(SendPacket(dh, cmd, 10, buf, MIN_TRANSFER_LEN, sense, DATA_READ) == 0)
    {  length = buf[0]<<8 | buf[1];
+      length_align(&length);
 
       Verbose("# size returned is %d\n", length);
 
@@ -1194,7 +1192,6 @@ static int query_blank(DeviceHandle *dh)
       length = buf[0]<<8 | buf[1];
       length += 2;    /* MMC3: "Disc information length excludes itself" */
       length_align(&length);
-
       Verbose("#CD: size returned is %d\n", length);
 
       if(length < 15 || length > 1024)  /* implausible */
@@ -1250,7 +1247,6 @@ static int query_blank(DeviceHandle *dh)
 	    length = buf[0]<<8 | buf[1];
 	    length += 2;    /* MMC3: "Disc information length excludes itself" */
 	    length_align(&length);
-
 	    Verbose("#DVD: size returned is %d\n", length);
 
 	    memset(cmd, 0, MAX_CDB_SIZE);
@@ -1478,8 +1474,7 @@ static void try_c2_scan(DeviceHandle *dh)
 
    ret = SendPacket(dh, cdb, 12, rb->workBuf->buf, CD_RAW_C2_SECTOR_SIZE, sense, DATA_READ);
 
-   Verbose("C2 scan probing: %d (%s); Sense: %s\n",
-	   ret, !ret ? "good" : "failed",
+   Verbose("C2 scan probing: %s\n", 
 	   GetSenseString(sense->sense_key, sense->asc, sense->ascq, 0));
 
    if(!ret || sense->sense_key != 5)  /* good status or error != illegal request means C2 works */
@@ -1519,8 +1514,8 @@ static int read_mode_page(DeviceHandle *dh, AlignedBuffer *ab, int *parameter_li
    ret  = SendPacket(dh, cdb, 10, buf, 252, &sense, DATA_READ);
 
    if(ret<0) 
-   {  Verbose("\nRead mode page 01h failed: %d (%s); Sense: %s\n", 
-	      ret, !ret ? "good" : "failed",
+   {  FreeAlignedBuffer(ab);
+      Verbose("\nRead mode page 01h failed: %s\n", 
 	      GetSenseString(sense.sense_key, sense.asc, sense.ascq, 0));
       return FALSE;
    }
@@ -1828,7 +1823,7 @@ static unsigned int query_size(DeviceHandle *dh)
    /*** If RS02 header search is enabled and we can find an appropriate header,
 	use it as an authoritative source for the medium size. */
 
-   if(Closure->querySize >= 2)
+   if(Closure->examineRS02)
    {  if(dh->rs02Size <= 0)
       {  gint64 last_sector = MAX(dh->readCapacity, dh->userAreaSize);
       
@@ -1851,16 +1846,14 @@ static unsigned int query_size(DeviceHandle *dh)
       Verbose("Skipping medium size determination from ECC header.\n");
    }
 
-   /*** If ISO/UDF filesystem parsing is enabled try this next. */
+   /*** Try getting the size from the ISO/UDF filesystem. */
 
-   if(Closure->querySize >= 1)
-   {  if(dh->isoInfo)
-      {  Verbose("Medium size obtained from ISO/UDF file system: %d sectors\n", 
-		 dh->isoInfo->volumeSize);  
-	 return dh->isoInfo->volumeSize;
-      }
-      else Verbose("Medium size could NOT be determined from ISO/UDF filesystem.\n");
-   } else Verbose("Skipping medium size determination from ISO/UDF filesystem.\n");
+   if(dh->isoInfo)
+   {  Verbose("Medium size obtained from ISO/UDF file system: %d sectors\n", 
+	      dh->isoInfo->volumeSize);  
+      return dh->isoInfo->volumeSize;
+   }
+   else Verbose("Medium size could NOT be determined from ISO/UDF filesystem.\n");
 
    /*** If everything else fails, query the drive. */
    
@@ -1904,7 +1897,7 @@ static unsigned int query_size(DeviceHandle *dh)
 			"READ DVD STRUCTURE: %lld sectors\n\n"),
 		      dh->readCapacity+1, dh->userAreaSize+1);
 
-      g_string_append(warning, _("Evaluation of returned medium sizes:\n\n"));
+      g_string_append_printf(warning, _("Evaluation of returned medium sizes:\n\n"));
 
       /*** Look at READ CAPACITY results */
 
@@ -2039,8 +2032,7 @@ gint64 CurrentMediumSize(int get_blank_size)
       size = dh->blankCapacity;
    }
    else
-   {  if(Closure->querySize >= 1)  /* parseUDF or better requested */
-	 ExamineUDF(dh);
+   {  ExamineUDF(dh, NULL);
       size = query_size(dh);
    }
 
@@ -2565,8 +2557,6 @@ DeviceHandle* OpenAndQueryDevice(char *device)
 
    Verbose("# *** OpenAndQueryDevice(%s) ***\n", device);
    dh = OpenDevice(device);
-   if(!dh) return NULL;
-
    InquireDevice(dh, 0);
    Verbose("# InquireDevice returned: %s\n", dh->devinfo);
 
@@ -2578,14 +2568,7 @@ DeviceHandle* OpenAndQueryDevice(char *device)
 		GetSenseString(dh->sense.sense_key, dh->sense.asc, dh->sense.ascq, FALSE));
    }
 
-#ifdef SYS_LINUX
    PrintLog(_("\nDevice: %s, %s\n"),device, dh->devinfo);
-#endif
-
-#ifdef SYS_MINGW
-   PrintLog(_("\nDevice: %s (%s), %s\n"),
-	    device, dh->aspiUsed ? "ASPI" : "SPTI", dh->devinfo);
-#endif
 
    /* Query the type and fail immediately if incompatible medium is found
       so that the later tests are not derailed by the wrong medium type */
@@ -2653,8 +2636,7 @@ DeviceHandle* OpenAndQueryDevice(char *device)
 
    /* Examine medium type */
 
-   if(Closure->querySize >= 1)  /* parseUDF or better requested */
-     ExamineUDF(dh);
+   ExamineUDF(dh, NULL);
 
    Verbose("# Calling query_size()\n");
    dh->sectors = query_size(dh);
@@ -2721,8 +2703,6 @@ DeviceHandle* QueryMediumInfo(char *device)
 
    Verbose("# *** QueryMediumInfo(%s) ***\n", device);
    dh = OpenDevice(device);
-   if(!dh) return NULL;
-
    InquireDevice(dh, 0);
 
    if(!TestUnitReady(dh))
@@ -2742,9 +2722,7 @@ DeviceHandle* QueryMediumInfo(char *device)
    /* Examine medium size (only on known/handled formats) */
 
    if(dh->subType != UNSUPPORTED)
-   {  if(Closure->querySize >= 1)  /* parseUDF or better requested */
-	 ExamineUDF(dh);
-
+   {  ExamineUDF(dh, NULL);
       dh->sectors = query_size(dh);
    }
 
@@ -2807,8 +2785,6 @@ int SendReadCDB(char *device, unsigned char *buf, unsigned char *cdb, int cdb_le
    int i,status;
 
    dh = OpenDevice(device);
-   if(!dh) return 0;
-
    InquireDevice(dh, 0);
 
    PrintLog("Sending cdb to device: %s, %s\n", device, dh->devinfo);
