@@ -1,5 +1,5 @@
 /*  dvdisaster: Additional error correction for optical media.
- *  Copyright (C) 2004-2012 Carsten Gnoerlich.
+ *  Copyright (C) 2004-2010 Carsten Gnoerlich.
  *  Project home page: http://www.dvdisaster.com
  *  Email: carsten@dvdisaster.com  -or-  cgnoerlich@fsfe.org
  *
@@ -36,8 +36,21 @@
 #include <camlib.h>
 #endif
 
+#ifdef SYS_DARWIN
+#define REAL_VERSION VERSION
+#undef VERSION
+#include <CoreFoundation/CoreFoundation.h>
+#include <IOKit/IOKitLib.h>
+#include <IOKit/scsi-commands/SCSITaskLib.h>
+#include <IOKit/storage/IODVDTypes.h>
+#include <mach/mach.h>
+#include <string.h>
+#include <stdlib.h>
+#define VERSION REAL_VERSION
+#endif
+
 /***
- *** Define the Sense data structure.
+ *** Global settings
  ***/
 
 /* Theretically not needed, but using less causes DMA breakage 
@@ -45,6 +58,10 @@
 
 #define MIN_TRANSFER_LEN 4  
 
+/***
+ *** Define the Sense data structure.
+ ***/
+
 /* 
  * Linux already has one 
  */
@@ -60,7 +77,7 @@
 #define MAX_CDB_SIZE SCSI_MAX_CDBLEN
 #endif
 
-#if defined(SYS_UNKNOWN) || defined(SYS_MINGW) || defined(SYS_NETBSD)
+#if defined(SYS_UNKNOWN) || defined(SYS_MINGW) || defined(SYS_NETBSD) || defined(SYS_DARWIN)
 #define MAX_CDB_SIZE 16   /* longest possible SCSI command */
 #endif
 
@@ -101,16 +118,20 @@ typedef struct _DeviceHandle
     */
 #if defined(SYS_LINUX) || defined(SYS_NETBSD) || defined(SYS_SOLARIS)
    int fd;                    /* device file descriptor */
-   int forceSG_IO;            /* CDROM_SEND_PACKET broken on this target */
 #endif
 #ifdef SYS_FREEBSD
    struct cam_device *camdev; /* camlib device handle */
    union ccb *ccb;
 #endif
 #ifdef SYS_MINGW
-   HANDLE fd;                 /* Windows file handle for the device (SPTI case) */
-   int aspiUsed;	      /* TRUE is device is accessed via ASPI */
-   int ha,target,lun;         /* ASPI way of describing drives */ 
+   HANDLE fd;                 /* Windows SPTI file handle for the device */
+#endif
+#ifdef SYS_DARWIN
+   IOCFPlugInInterface **plugInInterface;
+   MMCDeviceInterface **mmcDeviceInterface;
+   SCSITaskDeviceInterface **scsiTaskDeviceInterface;
+   SCSITaskInterface **taskInterface;
+   IOVirtualRange *range;
 #endif
    
    /*
@@ -122,7 +143,6 @@ typedef struct _DeviceHandle
    char vendor[34];           /* vendor and product info only */
 
    Sense sense;               /* sense data from last operation */
-   int senseSize;             /* OS may have differently sized struct */
 
    double singleRate;         /* supposed KB/sec @ single speed */
    int maxRate;               /* guessed maximum transfer rate */
@@ -237,7 +257,6 @@ typedef struct _DeviceHandle
 DeviceHandle* OpenDevice(char*);
 
 #ifdef SYS_MINGW
-DeviceHandle* open_aspi_device(char*, int);
 DeviceHandle* open_spti_device(char*);
 #endif
 
